@@ -249,14 +249,14 @@ pub fn select_window<'a>(
     prompt: &str,
     windows: &'a [Window],
 ) -> Option<&'a Window<'a>> {
-    util::select_from_choices(prompt, windows)
+    util::select_from_menu(prompt, windows)
 }
 
 pub fn select_workspace<'a>(
     prompt: &str,
     workspaces: &'a [Workspace],
 ) -> Option<&'a Workspace<'a>> {
-    util::select_from_choices(prompt, workspaces)
+    util::select_from_menu(prompt, workspaces)
 }
 
 pub enum WsOrWin<'a> {
@@ -306,7 +306,7 @@ pub fn select_workspace_or_window<'a>(
     prompt: &'a str,
     ws_or_wins: &'a [WsOrWin<'a>],
 ) -> Option<&'a WsOrWin<'a>> {
-    util::select_from_choices(prompt, ws_or_wins)
+    util::select_from_menu(prompt, ws_or_wins)
 }
 
 pub struct Workspace<'a> {
